@@ -3,7 +3,9 @@ import time
 import aiohttp
 import asyncio
 
-from .config import create_task_url, get_result_url, app_key, user_agent_data
+from .config import create_task_url, app_key, user_agent_data
+from .get_answer import get_sync_result, get_async_result
+
 
 class FunCaptchaTask:
 	def __init__(self, anticaptcha_key, proxyAddress, proxyPort, sleep_time=5, proxyType = 'http', **kwargs):
@@ -18,19 +20,22 @@ class FunCaptchaTask:
 		:param kwargs: Можно передать необязательные параметры и переопределить userAgent, все необязательные параметры
 						описаны в документации к API на сайте антикапчи
 		"""
+		if sleep_time < 5:
+			raise ValueError(f'Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}')
 		self.sleep_time = sleep_time
 		
 		# Пайлоад для создания задачи
 		self.task_payload = {"clientKey": anticaptcha_key,
-		                     "task":
-			                     {
-				                     "type": "FunCaptchaTask",
-				                     "userAgent": user_agent_data,
-				                     "proxyType": proxyType,
-				                     "proxyAddress": proxyAddress,
-				                     "proxyPort": proxyPort,
-			                     },
-		                     }
+							 "task":
+								 {
+									 "type": "FunCaptchaTask",
+									 "userAgent": user_agent_data,
+									 "proxyType": proxyType,
+									 "proxyAddress": proxyAddress,
+									 "proxyPort": proxyPort,
+								 },
+							 "softId": app_key
+							 }
 		
 		# пайлоад для получения ответа сервиса
 		self.result_payload = {"clientKey": anticaptcha_key}
@@ -41,7 +46,7 @@ class FunCaptchaTask:
 				self.task_payload['task'].update({key: kwargs[key]})
 		
 	# Работа с капчёй
-	def captcha_handler(self, websiteURL, websitePublicKey):
+	def captcha_handler(self, websiteURL, websitePublicKey, **kwargs):
 		"""
 		Метод получает ссылку на страницу на которпой расположена капча и ключ капчи
 		:param websiteURL: Ссылка на страницу с капчёй
@@ -49,10 +54,10 @@ class FunCaptchaTask:
 		:return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
 		"""
 		self.task_payload['task'].update({"websiteURL": websiteURL,
-		                                  "websiteKey": websitePublicKey})
+										  "websiteKey": websitePublicKey})
 		# Отправляем на антикапча параметры фанкапич,
 		# в результате получаем JSON ответ содержащий номер решаемой капчи
-		captcha_id = requests.post(create_task_url, json=self.task_payload).json()
+		captcha_id = requests.post(create_task_url, json=self.task_payload, **kwargs).json()
 
 		# Проверка статуса создания задачи, если создано без ошибок - извлекаем ID задачи, иначе возвращаем ответ сервера
 		if captcha_id['errorId'] == 0:
@@ -61,24 +66,10 @@ class FunCaptchaTask:
 			self.result_payload.update({"taskId": captcha_id})
 		else:
 			return captcha_id
-		
-		# Ожидаем решения капчи
+
+		# Ждем решения капчи
 		time.sleep(self.sleep_time)
-		while True:
-			# отправляем запрос на результат решения капчи, если не решена ожидаем
-			captcha_response = requests.post(get_result_url, json=self.result_payload)
-			
-			# Если ошибки нет - проверяем статус капчи
-			if captcha_response.json()['errorId'] == 0:
-				# Если капча ещё не готова- ожидаем
-				if captcha_response.json()["status"] == "processing":
-					time.sleep(self.sleep_time)
-				# если уже решена - возвращаем ответ сервера
-				else:
-					return captcha_response.json()
-			# Иначе возвращаем ответ сервера
-			else:
-				return captcha_response.json()
+		return get_sync_result(result_payload=self.result_payload, sleep_time=self.sleep_time)
 
 
 class aioFunCaptchaTask:
@@ -94,19 +85,22 @@ class aioFunCaptchaTask:
 		:param kwargs: Можно передать необязательные параметры и переопределить userAgent, все необязательные параметры
 						описаны в документации к API на сайте антикапчи
 		"""
+		if sleep_time < 5:
+			raise ValueError(f'Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}')
 		self.sleep_time = sleep_time
 		
 		# Пайлоад для создания задачи
 		self.task_payload = {"clientKey": anticaptcha_key,
-		                     "task":
-			                     {
-				                     "type": "FunCaptchaTask",
-				                     "userAgent": user_agent_data,
-				                     "proxyType": proxyType,
-				                     "proxyAddress": proxyAddress,
-				                     "proxyPort": proxyPort,
-			                     },
-		                     }
+							 "task":
+								 {
+									 "type": "FunCaptchaTask",
+									 "userAgent": user_agent_data,
+									 "proxyType": proxyType,
+									 "proxyAddress": proxyAddress,
+									 "proxyPort": proxyPort,
+								 },
+							 "softId": app_key
+							 }
 		
 		# пайлоад для получения ответа сервиса
 		self.result_payload = {"clientKey": anticaptcha_key}
@@ -125,7 +119,7 @@ class aioFunCaptchaTask:
 		:return: Возвращает ответ сервера в виде JSON(ответ так же можно глянуть в документации антикапчи)
 		"""
 		self.task_payload['task'].update({"websiteURL": websiteURL,
-		                                  "websiteKey": websitePublicKey})
+										  "websiteKey": websitePublicKey})
 		# Отправляем на антикапча параметры фанкапич,
 		# в результате получаем JSON ответ содержащий номер решаемой капчи
 		async with aiohttp.ClientSession() as session:
@@ -139,23 +133,7 @@ class aioFunCaptchaTask:
 			self.result_payload.update({"taskId": captcha_id})
 		else:
 			return captcha_id
-			
-		# Ожидаем решения капчи
+
+		# Ждем решения капчи
 		await asyncio.sleep(self.sleep_time)
-		# отправляем запрос на результат решения капчи, если не решена ожидаем
-		async with aiohttp.ClientSession() as session:
-			while True:
-				async with session.post(get_result_url, json=self.result_payload) as resp:
-					json_result = await resp.json()
-					
-					# Если ошибки нет - проверяем статус капчи
-					if json_result['errorId'] == 0:
-						# Если капча ещё не готова- ожидаем
-						if json_result["status"] == "processing":
-							await asyncio.sleep(self.sleep_time)
-						# если уже решена - возвращаем ответ сервера
-						else:
-							return json_result
-					# Иначе возвращаем ответ сервера
-					else:
-						return json_result
\ No newline at end of file
+		return await get_async_result(result_payload=self.result_payload, sleep_time=self.sleep_time)
